*
* Test for SET compact model
* Developed for HSPICE O-2018.09 within the EU H2020 project IONS4SET
* March 2019, Fabian J. Kluepfel, Fraunhofer IISB, Germany
*
* This HSPICE input file can be used to reproduce Fig. 12 (right part)
* of the article F. J. Klüpfel, IEEE Access 7, 84053-84065 (2019),
* DOI: 10.1109/ACCESS.2019.2924913
*
* This file is part of
* Compact Model for a Silicon Single Electron Transistor in a Stacked
* Nanopillar - Implementations in HSPICE and EXCEL/VBA
* Fabian J. Klüpfel and Peter Pichler
* Fraunhofer Institute for Integrated Systems and Device Technology IISB
* January 2021
* DOI: 10.24406/fordatis/116


.OPTION ingold=2 numdgt=7 post=2 lis_new=1 dcon=2 runlvl=6

.INCLUDE set_hspice_ions4set_ver5.mod

.PARAM T = 10
.PARAM nElec	= 1.	$ [1e20 cm-3] electrode carrier density
.PARAM ddot	= 3.2	$ [nm] quantum dot diameter
.PARAM hox	= 5.6	$ [nm] oxide thickness between source and drain
.PARAM dpil	= 10	$ [nm] silicon pillar diameter
.PARAM tgp	= 3	$ [nm] oxide thickness between gate and pillar
.PARAM hg	= 10	$ [nm] height of all-around-gate
.PARAM Qbg	= 4.0	$ [e] background charge


*** circuit description ***

Vdd 5 0 DC 0.04
* Vg 2 0 DC 0.0
Vs 3 0 DC 0.0

Vdmeas 5 1 DC 0.0

*     D G S
*     | | |
XSET1 1 2 6 SET TEMP=T nSrc=nElec nDrn=nElec nGte=nElec ddot=ddot hox=hox dpil=dpil tgp=tgp hg=hg Qbg=Qbg
Ri1 3 6 1e8

XSET2 1 6 7 SET TEMP=T nSrc=nElec nDrn=nElec nGte=nElec ddot=ddot hox=hox dpil=dpil tgp=tgp hg=hg Qbg=Qbg
Ri2 3 7 1e8

XSET3 1 7 8 SET TEMP=T nSrc=nElec nDrn=nElec nGte=nElec ddot=ddot hox=hox dpil=dpil tgp=tgp hg=hg Qbg=Qbg
Ri3 3 8 1e8

XSET4 1 8 9 SET TEMP=T nSrc=nElec nDrn=nElec nGte=nElec ddot=ddot hox=hox dpil=dpil tgp=tgp hg=hg Qbg=Qbg
Ri4 3 9 1e8

XSET5 1 9 2 SET TEMP=T nSrc=nElec nDrn=nElec nGte=nElec ddot=ddot hox=hox dpil=dpil tgp=tgp hg=hg Qbg=Qbg
Ri5 3 2 1e8


*** simulation control ***

.NODESET V(2)=0.03
.TRAN 40ps 40ns UIC
.PRINT TRAN V(2) V(6) V(7) V(8) V(9)

.END

